pub struct ShipModificationTransaction {
pub ship_symbol: String,
pub timestamp: DateTime<Utc>,
pub total_price: u64,
pub trade_symbol: String,
pub waypoint_symbol: String,
}Expand description
Result of a transaction for a ship modification, such as installing a mount or a module.
JSON schema
{
"description": "Result of a transaction for a ship modification, such as installing a mount or a module.",
"type": "object",
"required": [
"shipSymbol",
"timestamp",
"totalPrice",
"tradeSymbol",
"waypointSymbol"
],
"properties": {
"shipSymbol": {
"description": "The symbol of the ship that made the transaction.",
"type": "string"
},
"timestamp": {
"description": "The timestamp of the transaction.",
"type": "string",
"format": "date-time"
},
"totalPrice": {
"description": "The total price of the transaction.",
"type": "integer",
"minimum": 0.0
},
"tradeSymbol": {
"description": "The symbol of the trade good.",
"type": "string"
},
"waypointSymbol": {
"description": "The symbol of the waypoint where the transaction took place.",
"type": "string"
}
}
}Fields
ship_symbol: StringThe symbol of the ship that made the transaction.
timestamp: DateTime<Utc>The timestamp of the transaction.
total_price: u64The total price of the transaction.
trade_symbol: StringThe symbol of the trade good.
waypoint_symbol: StringThe symbol of the waypoint where the transaction took place.